==> hlw-core-0.0.2-20250422.075438-9-sources.jar: cn/gtmap/hlw/core/dto/third/cqxx/CqxxThirdQlrDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqxx;

import cn.gtmap.hlw.core.annotation.ZdDzConfig;
import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:wangzhiwen@gtmap.cn">wangzhiwen</a>
 * @version 1.0, 2023/6/12
 * @description
 */
@Data
public class CqxxThirdQlrDTO {
    /**
     * 权利人名称
     */
    private String qlrmc;
    /**
     * 权利人证件种类
     */
    private String qlrsfzjzl;
    /**
     * 权利人证件号
     */
    private String qlrzjh;
    /**
     * 权利人联系电话
     */
    private String qlrlxdh;
    /**
     * 权利人类型 代码(1:权利人，2义务人，3抵押权人,4借款人)
     */
    private String qlrlx;
    /**
     * 共有方式(代码)
     */
    private String gyfs;
    /**
     * 共有方式(名称)
     */
    private String gyfsmc;
    /**
     * 共有比例
     */
    private String qlbl;
    /**
     * 通讯地址
     */
    private String qlrtxdz;
    /**
     * 法定代表人或负责人
     */
    private String fddbrhfzr;
    /**
     * 法定代表人或负责人身份证件种类
     */
    private String fddbrhfzrsfzjzl;
    /**
     * 法定代表人或负责人证件号
     */
    private String fddbrhfzrzjh;
    /**
     * 法定代表人或负责人电话
     */
    private String fddbrhfzrdh;
    /**
     * 房产证号
     */
    private String fczh;
    /**
     * 数据来源（0：用户手填，1：第三方共享）
     */
    private String sjly;
    /**
     * 持证方式（1：共同持证，2：分别持证）
     */
    private String czfs;
    /**
     * 关系人种类代码
     */
    private String gxrzldm;
    /**
     * 顺序号
     */
    private String sxh;
    /**
     * 代理人电话
     */
    private String dlrdh;

    /**
     * 代理人名称
     */
    private String dlrmc;
    /**
     * 代理人证件号
     */
    private String dlrzjh;
    /**
     * 代理人身份证件种类
     */
    private String dlrsfzjzl;
    /**
     * 家庭成员信息
     */
    @ZdDzConfig(field = "jtcyxx", tableName = "", isList = true)
    private List<CqxxThirdQlrJtcyDTO> jtcyxx;
}

==> hlw-core-0.0.2-20251024.094938-166-sources.jar: cn/gtmap/hlw/core/dto/third/cqxx/CqxxThirdQlrDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqxx;

import cn.gtmap.hlw.core.annotation.ZdDzConfig;
import cn.gtmap.hlw.core.constant.dict.ZdDzConstant;
import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:wangzhiwen@gtmap.cn">wangzhiwen</a>
 * @version 1.0, 2023/6/12
 * @description
 */
@Data
public class CqxxThirdQlrDTO {
    /**
     * 权利人名称
     */
    private String qlrmc;
    /**
     * 权利人证件种类
     */
    @ZdDzConfig(field = "qlrsfzjzl", tableName = ZdDzConstant.ZD_DZ_ZJLX, mcToDM = true)
    private String qlrsfzjzl;
    /**
     * 权利人证件号
     */
    private String qlrzjh;
    /**
     * 权利人联系电话
     */
    private String qlrlxdh;
    /**
     * 权利人类型 代码(1:权利人，2义务人，3抵押权人,4借款人)
     */
    @ZdDzConfig(field = "qlrlx", tableName = ZdDzConstant.ZD_DZ_QLRLX, mcToDM = true)
    private String qlrlx;
    /**
     * 共有方式(代码)
     */
    @ZdDzConfig(field = "gyfs", tableName = ZdDzConstant.ZD_DZ_GYFS, mcToDM = true)
    private String gyfs;
    /**
     * 共有方式(名称)
     */
    private String gyfsmc;
    /**
     * 共有比例
     */
    private String qlbl;
    /**
     * 通讯地址
     */
    private String qlrtxdz;
    /**
     * 法定代表人或负责人
     */
    private String fddbrhfzr;
    /**
     * 法定代表人或负责人身份证件种类
     */
    private String fddbrhfzrsfzjzl;
    /**
     * 法定代表人或负责人证件号
     */
    private String fddbrhfzrzjh;
    /**
     * 法定代表人或负责人电话
     */
    private String fddbrhfzrdh;
    /**
     * 房产证号
     */
    private String fczh;
    /**
     * 数据来源（0：用户手填，1：第三方共享）
     */
    private String sjly;
    /**
     * 持证方式（1：共同持证，2：分别持证）
     */
    private String czfs;
    /**
     * 关系人种类代码
     */
    private String gxrzldm;
    /**
     * 顺序号
     */
    private String sxh;
    /**
     * 代理人电话
     */
    private String dlrdh;

    /**
     * 代理人名称
     */
    private String dlrmc;
    /**
     * 代理人证件号
     */
    private String dlrzjh;
    /**
     * 代理人身份证件种类
     */
    private String dlrsfzjzl;
    /**
     * 家庭成员信息
     */
    @ZdDzConfig(field = "jtcyxx", tableName = "", isList = true)
    private List<CqxxThirdQlrJtcyDTO> jtcyxx;
}
